@@ -3,7 +3,7 @@ use v5.24;
 use warnings;
 use experimental qw< signatures >;
 no warnings qw< experimental::signatures >;
-{ our $VERSION = '2.005' }
+{ our $VERSION = '2.007' }
 use Carp;
 
 use parent 'Exporter';
@@ -277,18 +277,16 @@ sub source_CmdLine ($self, $ignore, $args) {
 
    # Check if we want to forbid the residual @args to start with a '-'
    my $strict = !$self->allow_residual_options;
-   if ($strict && @args && $args[0] =~ m{\A -}mxs) {
-      Getopt::Long::Configure('default', 'gnu_getopt');
-      Getopt::Long::GetOptionsFromArray(\@args, {});
-      die "bailing out\n";
-   }
+   die "bailing out (allow_residual_options is false and got <@args>)"
+      if $strict && @args && $args[0] =~ m{\A - . }mxs;
 
    return (\%option_for, \@args);
 } ## end sub source_CmdLine
 
 sub name_for_option ($self, $o) {
    return $o->{name} if defined $o->{name};
-   return $1 if defined $o->{getopt} && $o->{getopt} =~ m{\A(\w+)}mxs;
+   return $1
+     if defined $o->{getopt} && $o->{getopt} =~ m{\A(\w[-\w]*)}mxs;
    return lc $o->{environment}
      if defined $o->{environment} && $o->{environment} ne '1';
    return '~~~';
@@ -653,10 +651,8 @@ sub list_commands_for ($self, $target = undef) {
    return join "\n", @lines;
 } ## end sub list_commands_for
 
-sub help_channel ($self) { $self->target->help_channel }
-
 sub _build_printout_facility ($self) {
-   my $channel = $self->help_channel;
+   my $channel = $self->target->help_channel;
    my $refch = ref $channel;
 
    return $channel if $refch eq 'CODE';
@@ -827,7 +823,7 @@ sub collect_help_for ($self, $target = undef) {
    $target //= $self->target;
    my @stuff;
 
-   push @stuff, $target->help, "\n\n";
+   push @stuff, ($target->help // 'no concise help yet'), "\n\n";
 
    if (defined(my $description = $target->description)) {
       $description =~ s{\A\s+|\s+\z}{}gmxs;    # trim
